@@ -229,10 +229,11 @@ tsEvaComputeReturnLevelsGEV <- function(epsilon, sigma, mu, epsilonStdErr, sigma
   npars <- length(sigma)
   nt <- length(returnPeriodsInDts)
   yp <- matrix(yp, nrow = npars, ncol = nt, byrow = TRUE)
-  sigma_ <- matrix(sigma, nrow = npars, ncol = nt, byrow = TRUE)
-  sigmaStdErr_ <- matrix(sigmaStdErr, nrow = npars, ncol = nt, byrow = TRUE)
-  mu_ <- matrix(mu, nrow = npars, ncol = nt, byrow = TRUE)
-  muStdErr_ <- matrix(muStdErr, nrow = npars, ncol = nt, byrow = TRUE)
+  sigma_ <- t(matrix(sigma, nrow = nt, ncol = npars, byrow = TRUE))
+  sigmaStdErr_ <- t(matrix(sigmaStdErr, nrow = nt, ncol = npars, byrow = TRUE))
+  mu_ <- t(matrix(mu, nrow = nt, ncol = npars, byrow = TRUE))
+  muStdErr_ <- t(matrix(muStdErr, nrow = nt, ncol = npars, byrow = TRUE))
+
   if (epsilon != 0) {
     # estimating the return levels
     returnLevels <- mu_ - sigma_ / epsilon * (1 - yp^(-epsilon))
@@ -381,11 +382,17 @@ tsEvaComputeReturnLevelsGPD <- function(epsilon, sigma, threshold, epsilonStdErr
   XX <- X0 * returnPeriods
   npars <- length(sigma)
   nt <- length(returnPeriods)
+
   XX_ <- rep(XX, each = npars)
+  #XX_<-(matrix(XX, nrow = npars, ncol = nt, byrow = TRUE))
+  #sigma_ <- t(matrix(sigma, nrow = nt, ncol = npars, byrow = TRUE))
+  #sigmaStdErr_ <- t(matrix(sigmaStdErr, nrow = nt, ncol = npars, byrow = TRUE))
   sigma_ <- rep(sigma, times = nt)
   sigmaStdErr_ <- rep(sigmaStdErr, times = nt)
   threshold_ <- rep(threshold, times = nt)
   thresholdStdErr_ <- rep(thresholdStdErr, times = nt)
+  #threshold_ <- t(matrix(threshold, nrow = nt, ncol = npars, byrow = TRUE))
+  #thresholdStdErr_ <- t(matrix(thresholdStdErr, nrow = nt, ncol = npars, byrow = TRUE))
 
   if (epsilon != 0) {
     # estimating the return levels
@@ -617,7 +624,7 @@ tsEvaComputeRLsGEVGPD<-function(nonStationaryEvaParams, RPgoal, timeIndex,trans=
 #'     \item{\code{monthlyMaxIndx}}{The indices of the monthly maximum values.}
 #'   }
 #' @seealso [tsGetPOT()]
-#' @import stats
+
 #' @examples
 #' # Generate sample data
 #' data <- ArdecheStMartin
@@ -646,7 +653,7 @@ tsEvaSampleData <- function(ms, meanEventsPerYear,minEventsPerYear, minPeakDista
 
   POTData <- tsGetPOT(ms, potPercentiles, meanEventsPerYear,minEventsPerYear,minPeakDistanceInDays, tail)
 
-  vals <- quantile(ms[,2], pctsDesired/100,na.rm=T)
+  vals <- stats::quantile(ms[,2], pctsDesired/100,na.rm=T)
   percentiles <- list(precentiles = pctsDesired, values = vals)
 
   pointData <- list()
@@ -670,8 +677,6 @@ tsEvaSampleData <- function(ms, meanEventsPerYear,minEventsPerYear, minPeakDista
   return(pointData)
 }
 
-
-
 #' tsGetPOT Function
 #'
 #' \code{tsGetPOT} is a function that calculates the Peaks Over Threshold (POT)
@@ -700,7 +705,6 @@ tsEvaSampleData <- function(ms, meanEventsPerYear,minEventsPerYear, minPeakDista
 #'   fitted to the peaks.}
 #' }
 #'
-#' @import stats
 #' @importFrom POT fitgpd
 #' @seealso [tsEvaSampleData()]
 #' @examples
@@ -751,7 +755,7 @@ tsGetPOT <- function(ms, pcts, desiredEventsPerYear,minEventsPerYear, minPeakDis
       skip=skip-1
     }else{
       if(dej==0){
-        thrsdt <- quantile(ms[,2],pcts[ipp]/100,na.rm=T)
+        thrsdt <- stats::quantile(ms[,2],pcts[ipp]/100,na.rm=T)
         thrsdts[ipp] <- thrsdt
         ms[,2][which(is.na(ms[,2]))]=-9999
         minEventsPerYear=1
@@ -763,45 +767,67 @@ tsGetPOT <- function(ms, pcts, desiredEventsPerYear,minEventsPerYear, minPeakDis
         }
         if(tail=="low") {
           pks <- declustpeaks(data = ms[,2] ,minpeakdistance = minPeakDistance ,minrundistance = minRunDistance, qt=thrsdt)
-          shape_bnd=c(-1.5,0)
+          shape_bnd=c(-2,0)
         }
         numperyear[ipp] <- length(pks[,1])/nyears
         if(numperyear[ipp]>=3*desiredEventsPerYear & ipp<(length(pcts)-5)) skip = floor(length(pcts)/8)
-        if(numperyear[ipp]<minEventsPerYear) {
-          perfpen=(pcts[ipp]*100)
+        if(numperyear[ipp]<0.9*minEventsPerYear) {
+          perfpen=(pcts[ipp])*100
         }
         if(numperyear[ipp]<(0.7*minEventsPerYear)) {
-          perfpen=9999*(pcts[ipp]*100)
+          perfpen=(pcts[ipp])*1000
         }
         if(numperyear[ipp]<=desiredEventsPerYear+1 & dej==0){
-          fgpd=suppressWarnings(POT::fitgpd(pks[,1], threshold = thrsdt, est = "mle",method="BFGS",std.err.type = "expected"))
-          gpdpar=fgpd$fitted.values
-          deviance=fgpd$deviance
-          devpp[ipp]=AIC(fgpd)+perfpen
-          gpp[ipp]=gpdpar[2]
+          fgpd=suppressWarnings(try(POT::fitgpd(pks[,1], threshold = thrsdt, est = "mle",method="BFGS",std.err.type = "expected")))
+          if(inherits(fgpd, "try-error")){
+            gpdpar=9999
+            deviance=9999
+            devpp[ipp]=1e9
+            gpp[ipp]=9999
+          }else {
+            gpdpar=fgpd$fitted.values
+            deviance=fgpd$deviance
+            devpp[ipp]=stats::AIC(fgpd)+perfpen
+            gpp[ipp]=gpdpar[2]
+          }
           nperYear <- tsGetNumberPerYear(ms, pks[,2])
           minnumperyear[ipp] <- min(nperYear$Freq, na.rm = TRUE)
         }
       }
     }
   }
+
+  #peaks with lowest threshold (retrieving the two largest peaks)
+  pkx <- declustpeaks(data = ms[,2] ,minpeakdistance = minPeakDistance ,minrundistance = minRunDistance, qt=stats::quantile(ms[,2],pcts[1]/100,na.rm=T))
+  md= abs(pkx[1,1]-pkx[2,1])
   devpp[1]=NA
   if(is.na(trip)){
     isok=F
-    count=0
     devpx=devpp
-    #discard the fits that provide negative values
+    count=1
     while(isok==F){
-      trip=which.min(devpx)
-      isok=dplyr::between(gpp[trip], shape_bnd[1], shape_bnd[2])
+      #safety measure for stability of parameter
+      dshap=c(0,diff(gpp))
+      #Penalizing fits with positive shape parameters for low tail
+      if(tail=="low") {
+        #for very bounded distributions
+        if (md<0.1){
+          devpp[which(gpp>=-0.5)]=devpp[which(gpp>=-0.5)]+9999
+        }else{
+          devpp[which(gpp>=0)]=devpp[which(gpp>=0)]+9999
+        }
+
+      }
+      devpp[which(abs(dshap)>0.5)]=devpp[which(abs(dshap)>0.5)]+99999
+      trip=which.min(devpp)
+      #message(paste0("shape outside boudaries: ",round(gpp[trip],2)))
+      #isok=T
+      #trip=which.min(devpx)
+      isok=dplyr::between(round(gpp[trip],1), shape_bnd[1], shape_bnd[2])
       count=count+1
       if(isok==F)devpx[trip]=devpx[trip]+9999
       if(count>(length(devpx)-1)){
         #safety measure for stability of parameter
-        dshap=c(0,diff(gpp))
-        #Penalizing fits with positive shape parameters for low tail
-        if(tail=="low") devpp[which(gpp>=0)]=devpp[which(gpp>=0)]+99999
-        devpp[which(abs(dshap)>0.5)]=devpp[which(abs(dshap)>0.5)]+9999
         trip=which.min(devpp)
         message(paste0("shape outside boudaries: ",round(gpp[trip],2)))
         isok=T
@@ -809,15 +835,16 @@ tsGetPOT <- function(ms, pcts, desiredEventsPerYear,minEventsPerYear, minPeakDis
     }
   }
   message(paste0("\nmax threshold is: ", pcts[trip],"%"))
+  message(paste0("\nshape parameter is: ", round(gpp[trip],2)))
   message(paste0("\naverage number of events per year = ",round(numperyear[trip],1) ))
 
-  diffNPerYear <- mean(diff(na.omit(rev(numperyear)), na.rm = TRUE))
+  diffNPerYear <- mean(diff(stats::na.omit(rev(numperyear)), na.rm = TRUE))
   if (diffNPerYear == 0) diffNPerYear <- 1
   diffNPerYear <- 1
-  thresholdError <- -mean(diff(na.omit(thrsdts))/diffNPerYear)/2
+  thresholdError <- -mean(diff(stats::na.omit(thrsdts))/diffNPerYear)/2
   indexp <- trip
   if (!is.na(indexp)) {
-    thrsd <- quantile(ms[,2],pcts[indexp]/100)
+    thrsd <- stats::quantile(ms[,2],pcts[indexp]/100)
     pct <- pcts[indexp]
   } else {
     thrsd <- 0
@@ -832,7 +859,6 @@ tsGetPOT <- function(ms, pcts, desiredEventsPerYear,minEventsPerYear, minPeakDis
   locs <- pks_and_locs[,2]
   st<-pks_and_locs[,3]
   end=pks_and_locs[,4]
-
   # Create a list to store results
   POTdata <- list()
   # Assign values to the fields of the list
@@ -964,19 +990,19 @@ tsEVstatistics <- function(pointData, alphaCI = 0.95, gevMaxima = 'annual', gevT
         if (stdfit==TRUE){
           probs <- c(alphaCIx/2, 1-alphaCIx/2)
           # Compute the CI for k using a normal distribution for khat.
-          kci <- try(qnorm(probs, paramEsts[3], fit$std.err[3]),TRUE)
+          kci <- try(stats::qnorm(probs, paramEsts[3], fit$std.err[3]),TRUE)
           kci[kci < -1] <- -1
           # Compute the CI for sigma using a normal approximation for log(sigmahat)
           # and transform back to the original scale.
-          lnsigci <- try(qnorm(probs, log(paramEsts[2]), fit$std.err[2]/paramEsts[2]),silent=T)
-          muci <- qnorm(probs, paramEsts[1], fit$std.err[1])
+          lnsigci <- try(stats::qnorm(probs, log(paramEsts[2]), fit$std.err[2]/paramEsts[2]),silent=T)
+          muci <- stats::qnorm(probs, paramEsts[1], fit$std.err[1])
           paramCIs <- cbind(muci=muci, sigci=exp(lnsigci), kci=kci)
         }else{
           #not able to generate parameters CI
           paramCIs <- cbind(muci=NA, sigci=NA, kci=NA)
         }
       } else if (gevType == "gumbel"){
-        fit <- texmex::evm(y = dt, data = tmp, family = gumbel)
+        fit <- texmex::evm(y = .data$dt, data = tmp, family = gumbel)
         paramEsts <- c(fit$par[1], exp(fit$par[2]),0)
 
         alphaCIx=1-alphaCI
@@ -992,9 +1018,9 @@ tsEVstatistics <- function(pointData, alphaCI = 0.95, gevMaxima = 'annual', gevT
           kci <- c(NA,NA)
           # Compute the CI for sigma using a normal approximation for log(sigmahat)
           # and transform back to the original scale.
-          lnsigci <- try(qnorm(probs, log(paramEsts[2]), fit$se[2]))
+          lnsigci <- try(stats::qnorm(probs, log(paramEsts[2]), fit$se[2]))
 
-          muci <- qnorm(probs, paramEsts[1], fit$se[1])
+          muci <- stats::qnorm(probs, paramEsts[1], fit$se[1])
           paramCIs <- cbind(muci=muci, sigci=exp(lnsigci), kci=kci)
         }
       }
@@ -1041,11 +1067,11 @@ tsEVstatistics <- function(pointData, alphaCI = 0.95, gevMaxima = 'annual', gevT
       sgm <- fit$par[1]
       alphaCIx=1-alphaCI
       probs <- c(alphaCIx/2, 1-alphaCIx/2)
-      kci <- try(qnorm(probs, ksi, fit$std.err[2]),silent=T)
+      kci <- try(stats::qnorm(probs, ksi, fit$std.err[2]),silent=T)
       kci[kci < -1] <- -1
       # Compute the CI for sigma using a normal approximation for log(sigmahat)
       # and transform back to the original scale.
-      lnsigci <- try(qnorm(probs, log(sgm), fit$std.err[1]/sgm))
+      lnsigci <- try(stats::qnorm(probs, log(sgm), fit$std.err[1]/sgm))
       paramCIs <- cbind(kci, sigci=exp(lnsigci))
 
       # Create output structures for GPD statistics
@@ -1236,14 +1262,18 @@ computeAnnualMaxima <- function(timeAndSeries) {
 #' @export
 computeMonthlyMaxima<- function(timeAndSeries) {
   timeStamps <- timeAndSeries[,1]
+  dt1=min(diff(timeStamps),na.rm=T)
+  dt=as.numeric(dt1)
+  tdim=attributes(dt1)$units
+  tmvec <- as.Date(timeStamps)
+  if (tdim!="days")   tmvec <- as.Date(timeStamps+3600)
   srs <- timeAndSeries[,2]
 
-  tmvec <- as.Date(timeStamps+3600)
   yrs <- as.integer(format(tmvec, "%Y"))
   mnts <- as.integer(format(tmvec, "%m"))
   mnttmvec <- data.frame(yrs, mnts)
   valsIndxs <- 1:length(srs)
-  monthlyMaxIndx <- aggregate(valsIndxs ~ yrs + mnts, data = mnttmvec, function(x) {
+  monthlyMaxIndx <- stats::aggregate(valsIndxs ~ yrs + mnts, data = mnttmvec, function(x) {
     findMax(x,srs)
   })
   monthlyMaxIndx$valsIndxs=as.numeric(monthlyMaxIndx$valsIndxs)
@@ -1267,7 +1297,7 @@ computeMonthlyMaxima<- function(timeAndSeries) {
 #' @param minpeakdistance An integer specifying the minimum distance between peaks.
 #' @param minrundistance An integer specifying the minimum distance between runs.
 #' @param qt A numeric value representing the threshold for peak detection.
-#' @import texmex stats
+#' @import texmex
 #' @return A data frame with information about the peaks, including:
 #' \describe{
 #'   \item{\code{Q}}{the peak value}
@@ -1291,7 +1321,7 @@ declustpeaks<-function(data,minpeakdistance = 10 ,minrundistance = 7, qt){
   peakex=data.frame(Qval,intcl, peakev$clusters,peakev$isClusterMax,peakev$exceedanceTimes)
   names(peakex)=c("Qs","Istart","clusters","IsClustermax","exceedances")
   evmax=peakex[which(peakex$IsClustermax==T),]
-  ziz=aggregate(peakex$exceedance,
+  ziz=stats::aggregate(peakex$exceedance,
                 by=list(clust=peakex$clusters), FUN=function(x) c(max(x)-min(x)+1))
   st=stats::aggregate(peakex$exceedance,
                by=list(clust=peakex$clusters), FUN=function(x) c(min(x)))
