@@ -37,6 +37,9 @@
 #'  \item{\code{lninv}}{log of inverse the data (used for low extreme, under development)}
 #'  }
 #' @param lowdt The temporal resolultion used for low values. default is 7 days.
+#' @param TrendTh The threshold used to compute the trend on extreme events
+#' (only valid if transftype==trendPeaks). If not specified, the optimal
+#' threshold is identified within the function
 #'
 #' @return A list containing the results of the non-stationary EVA.
 #' Containing the following components:
@@ -82,46 +85,7 @@
 TsEvaNs<- function(timeAndSeries, timeWindow, transfType='trendPeaks',minPeakDistanceInDays=10,
                    seasonalityVar=NA,minEventsPerYear=-1, gevMaxima='annual',
                    ciPercentile=90, gevType = 'GEV', evdType = c('GEV', 'GPD'),
-                   tail="high", epy=-1, lowdt=7, trans=NULL){
-
-  # ota=list(transfType = transfType,
-  #          minPeakDistanceInDays = minPeakDistanceInDays,
-  #          seasonalityVar = seasonalityVar,
-  #          minEventsPerYear = minEventsPerYear,
-  #          gevMaxima = gevMaxima,
-  #          ciPercentile = ciPercentile,
-  #          gevType = gevType,
-  #          evdType =evdType,
-  #          tail= tail,
-  #          epy= epy,
-  #          lowdt=lowdt,
-  #          trans=trans
-  #          )
-  # args <- list(transfType = 'trendPeaks',
-  #              minPeakDistanceInDays = -1,
-  #              seasonalityVar = F,
-  #              minEventsPerYear = -1,
-  #              gevMaxima = 'annual',
-  #              ciPercentile = 90,
-  #              gevType = 'GEV',
-  #              evdType = c('GEV', 'GPD'),
-  #              tail="low",
-  #              epy=-1,
-  #              trans=NULL,
-  #              lowdt=7)
-  #
-  # args <- tsEasyParseNamedArgs(ota, args)
-  # seasonalityVar<-args$seasonalityVar
-  # ciPercentile <- args$ciPercentile
-  # transfType <- args$transfType
-  # evdType <- args$evdType
-  # gevType <- args$gevType
-  # TrendTh <- args$TrendTh
-  # epy <- args$epy
-  # tail=args$tail
-  # lowdt=args$lowdt
-  # minPeakDistanceInDays<-args$minPeakDistanceInDays
-  # trans=args$trans
+                   tail="high", epy=-1, lowdt=7, trans=NULL, TrendTh=NA){
 
 
   timeStamps=as.POSIXct(timeAndSeries[,1])
@@ -168,7 +132,7 @@ TsEvaNs<- function(timeAndSeries, timeWindow, transfType='trendPeaks',minPeakDis
     indices_to_extract <- seq(from = start_index, to = length(series), by = lowdt/dt)
     series=series[indices_to_extract]
     timeStamps=timeStamps[indices_to_extract]
-    shape_bnd=c(-1,0)
+    shape_bnd=c(-2,0)
     if (trans=="rev"){
       series=-1*series
     }else if(trans=="inv"){
@@ -176,7 +140,6 @@ TsEvaNs<- function(timeAndSeries, timeWindow, transfType='trendPeaks',minPeakDis
     }else if (trans=="lninv"){
       series=-log(series)
     }
-
   }
   if (transfType == 'trend'){
     message('\nevaluating long term variations of extremes')
@@ -212,11 +175,26 @@ TsEvaNs<- function(timeAndSeries, timeWindow, transfType='trendPeaks',minPeakDis
 
   }else if (transfType == 'trendPeaks') {
     message(paste0('\nevaluating long term variations of the peaks'))
-    TrendTh=try(tsEvaFindTrendThreshold(series, timeStamps, timeWindow),T)
-    if(length(TrendTh)==0){
-      TrendTh=NA
+    if (is.na(TrendTh)){
+      TrendTh=try(tsEvaFindTrendThreshold(series, timeStamps, timeWindow),T)
+      if(length(TrendTh)==0){
+        TrendTh=0.1
+      }
+      print(TrendTh)
+      trasfData = tsEvaTransformSeriesToStationaryPeakTrend( timeStamps, series, timeWindow, TrendTh);
+    }else{
+      if (TrendTh=="MMX"){
+        trasfData = tsEvaTransformSeriesToStationaryMMXTrend( timeStamps, series, timeWindow);
+        message("using MMX trend")
+      }else{
+        trasfData = tsEvaTransformSeriesToStationaryPeakTrend( timeStamps, series, timeWindow, TrendTh);
+        c=0
+        while ((length(unique(trasfData$trendSeries))<2)) {
+          trasfData = tsEvaTransformSeriesToStationaryPeakTrend( timeStamps, series, timeWindow, TrendTh=TrendTh-c);
+          c=c+0.1
+        }
+      }
     }
-    trasfData = tsEvaTransformSeriesToStationaryPeakTrend( timeStamps, series, timeWindow, TrendTh);
     gevMaxima = 'annual'
     potEventsPerYear = epy
     minEventsPerYear = 1
@@ -477,3 +455,5 @@ TsEvaNs<- function(timeAndSeries, timeWindow, transfType='trendPeaks',minPeakDis
   return(list(nonStationaryEvaParams=nonStationaryEvaParams,stationaryTransformData=stationaryTransformData))
 
 }
+
+
