@@ -132,14 +132,13 @@ tsEvaTransformSeriesToStationaryTrendOnly <- function(timeStamps, series, timeWi
 #'result <- tsEvaTransformSeriesToStationaryTrendOnly_ciPercentile(timeStamps,
 #'series, timeWindow, percentile)
 #'plot(result$trendSeries)
-#' @import stats
 #' @export
 tsEvaTransformSeriesToStationaryTrendOnly_ciPercentile <- function(timeStamps,
   series, timeWindow, percentile) {
 
   # Removing trend from the series
   message("\ncomputing the trend on extremes...\n")
-  qtes <- quantile(series, percentile / 100, na.rm = T)
+  qtes <- stats::quantile(series, percentile / 100, na.rm = T)
   rs <- tsEvaDetrendTimeSeries(timeStamps, series, timeWindow)
   meantrend <- mean(series)
   trendseriesf <- rs@trendSeries
@@ -147,7 +146,7 @@ tsEvaTransformSeriesToStationaryTrendOnly_ciPercentile <- function(timeStamps,
   nRunMn <- rs@nRunMn
 
   # Compute the extreme trend of the stationary series
-  qtes <- quantile(detrendSeries, percentile / 100, na.rm = T)
+  qtes <- stats::quantile(detrendSeries, percentile / 100, na.rm = T)
   detrendseriep <- detrendSeries
   detrendseriep[which(detrendseriep < qtes)] <- NA
   percentileSeries <- tsEvaNanRunningMean(detrendseriep, nRunMn)
@@ -158,7 +157,7 @@ tsEvaTransformSeriesToStationaryTrendOnly_ciPercentile <- function(timeStamps,
   if (min(percentileSeries, na.rm = T) < 0) percentileSeries <- percentileSeries - min(percentileSeries)
 
   meanperc <- mean(detrendseriep, na.rm = T)
-  stdDev <- sd(detrendSeries, na.rm = T)
+  stdDev <- stats::sd(detrendSeries, na.rm = T)
 
   # real std
   varianceSeries <- tsEvaNanRunningVariance(detrendSeries, nRunMn)
@@ -215,7 +214,7 @@ tsEvaTransformSeriesToStationaryTrendOnly_ciPercentile <- function(timeStamps,
 #' @param series A vector of the time series data.
 #' @param timeWindow The size of the time window used for detrending.
 #' @param TrendTh The threshold for fitting the trend on the means above a
-#' given quantile. Default is 0.5.
+#' given quantile. If "NA", default to 0.5.
 #'
 #' @return A list containing the following components:
 #'   \describe{
@@ -233,7 +232,6 @@ tsEvaTransformSeriesToStationaryTrendOnly_ciPercentile <- function(timeStamps,
 #'    \item{\code{statSer4Mom}}{The running mean of the fourth moment of the stationary series.}
 #'   }
 #'
-#' @import stats
 #' @examples
 #'timeAndSeries <- ArdecheStMartin
 #'timeStamps <- ArdecheStMartin[,1]
@@ -262,54 +260,160 @@ tsEvaTransformSeriesToStationaryPeakTrend <- function(timeStamps, series, timeWi
     TrendTh <- 0.5
   }
   message(paste0("trend threshold= ", TrendTh))
-  qd <- quantile(series, TrendTh, na.rm = T)
-  serieb <- series
-  serieb[which(serieb < qd)] <- NA
+  qd <- stats::quantile(series, TrendTh, na.rm = T)
+  series_above_threshold <- series
+  series_above_threshold[which(series_above_threshold < qd)] <- NA
 
 
-  rs <- tsEvaDetrendTimeSeries(timeStamps, serieb, timeWindow)
+  detrend_result <- tsEvaDetrendTimeSeries(timeStamps, series_above_threshold, timeWindow)
 
-  # adding the threshold to avoid values on the zero
-  detrendSeries <- series - rs@trendSeries
-  detrendSerie1 <- serieb - rs@trendSeries
-  qd2 <- min(detrendSerie1, na.rm = T)
-  nRunMn <- rs@nRunMn
+  # Detrend the series
+  detrended_series <- series - detrend_result@trendSeries
+  detrended_series_above_threshold <- series_above_threshold - detrend_result@trendSeries
 
-  varianceSeries <- tsEvaNanRunningVariance(detrendSerie1, nRunMn)
-  # further smoothing
-  varianceSeries <- tsEvaNanRunningMean(varianceSeries, ceiling(nRunMn / 2))
-
-  stdDevSeries1 <- varianceSeries^.5
-  stdDevSeries <- stdDevSeries1
-  avgStdDev <- mean(stdDevSeries)
+  # Calculate running variance and standard deviation
+  n_run_mean <- detrend_result@nRunMn
+  variance_series <- tsEvaNanRunningVariance(detrended_series_above_threshold, n_run_mean)
+  variance_series <- tsEvaNanRunningMean(variance_series, ceiling(n_run_mean / 2))
+  std_dev_series <- sqrt(variance_series)
+  avg_std_dev <- mean(std_dev_series, na.rm = TRUE)
   S <- 2
 
-  # N is the size of each sample used to compute the average
-  # Counts the real amount of timstep, need to specify original temporal resolution
+  # Calculate error on standard deviation
+  N <- timeWindow * 4
+  std_dev_error <- avg_std_dev * (2 * S^2 / N^3)^(1 / 4)
+
+  # Compute running statistics of the stationary series
+  stationary_series <- detrended_series / std_dev_series
+  stationary_series_no_na <- stats::na.omit(stationary_series)
+
+  running_moments <- tsEvaNanRunningStatistics(stationary_series_no_na, n_run_mean)
+  stat_ser_3_mom <- tsEvaNanRunningMean(running_moments$rn3mom, ceiling(n_run_mean))
+  stat_ser_4_mom <- tsEvaNanRunningMean(running_moments$rn4mom, ceiling(n_run_mean))
+
+  # Calculate error on the trend
+  trend_error <- avg_std_dev / sqrt(N)
+
+  # Store the results in a list
+  transformed_data <- list(
+    runningStatsMulteplicity = n_run_mean,
+    stationarySeries = stationary_series,
+    trendSeries = detrend_result@trendSeries,
+    trendSeriesNonSeasonal = NULL,
+    trendError = trend_error,
+    stdDevSeries = std_dev_series,
+    stdDevSeriesNonSeasonal = NULL,
+    stdDevError = std_dev_error * rep(1, length(std_dev_series)),
+    timeStamps = timeStamps,
+    nonStatSeries = series,
+    statSer3Mom = stat_ser_3_mom,
+    statSer4Mom = stat_ser_4_mom
+  )
+
+  return(transformed_data)
+}
+
+#' tsEvaTransformSeriesToStationaryMMXTrend
+#'
+#' \code{tsEvaTransformSeriesToStationaryMMXTrend}
+#' transforms a time series to a stationary one by focusing on the monthly maximum values.
+#' The trend and slowly varying amplitude are computed on the monthly maximum values.
+#'
+#' @param timeStamps A vector of time stamps corresponding to the observations in the series.
+#' @param series A vector of the time series data.
+#' @param timeWindow The size of the time window used for detrending.
+#'
+#' @return A list containing the following components:
+#'   \describe{
+#'    \item{\code{runningStatsMulteplicity}}{The multiplicity of running statistics.}
+#'    \item{\code{stationarySeries}}{The stationary series after removing the trend.}
+#'    \item{\code{trendSeries}}{The trend component of the series.}
+#'    \item{\code{trendSeriesNonSeasonal}}{NULL (not used).}
+#'    \item{\code{trendError}}{The error on the trend component.}
+#'    \item{\code{stdDevSeries}}{The standard deviation series.}
+#'    \item{\code{stdDevSeriesNonSeasonal}}{NULL (not used).}
+#'    \item{\code{stdDevError}}{The error on the standard deviation series.}
+#'    \item{\code{timeStamps}}{The time stamps.}
+#'    \item{\code{nonStatSeries}}{The original non-stationary series.}
+#'    \item{\code{statSer3Mom}}{The running mean of the third moment of the stationary series.}
+#'    \item{\code{statSer4Mom}}{The running mean of the fourth moment of the stationary series.}
+#'   }
+#'
+#' @import dplyr
+#' @importFrom dplyr mutate group_by summarise
+#' @importFrom lubridate floor_date
+#' @examples
+#' timeAndSeries <- ArdecheStMartin
+#' timeStamps <- ArdecheStMartin[,1]
+#' series <- ArdecheStMartin[,2]
+#' # select only the 5 latest years
+#' yrs <- as.integer(format(timeStamps, "%Y"))
+#' tokeep <- which(yrs >= 2015)
+#' timeStamps <- timeStamps[tokeep]
+#' series <- series[tokeep]
+#' timeWindow <- 365 # 1 year
+#' result <- tsEvaTransformSeriesToStationaryMMXTrend(timeStamps, series, timeWindow)
+#' plot(result$trendSeries)
+#'
+#' @seealso [tsEvaDetrendTimeSeries()], [tsEvaNanRunningVariance()],
+#' [tsEvaNanRunningMean()], [tsEvaNanRunningStatistics()]
+#' @export
+tsEvaTransformSeriesToStationaryMMXTrend <- function(timeStamps, series, timeWindow) {
+  # Check if timeStamps and series are of the same length
+  if (length(timeStamps) != length(series)) {
+    stop("timeStamps and series must be of the same length.")
+  }
+
+  # Check if timeWindow is a positive integer
+  if (!is.numeric(timeWindow) || timeWindow <= 0) {
+    stop("timeWindow must be a positive integer.")
+  }
+
+  # Create a data frame with timeStamps and series
+  tserie <- data.frame(timeStamps, series)
+
+  # Calculate monthly maximum values
+  monthly_max <- tserie %>%
+    dplyr::mutate(month = lubridate::floor_date(timeStamps, "month")) %>%
+    dplyr::group_by(month) %>%
+    dplyr::summarise(max_value = max(series, na.rm = TRUE))
+
+  # Create a series with only the monthly maximum values
+  serieb <- series
+  tm <- stats::na.omit(match(as.Date(as.character(monthly_max$month)), as.Date(timeStamps)))
+  serieb[-tm] <- NA
+
+  # Detrend the series based on monthly maximum values
+  rs <- tsEvaDetrendTimeSeries(timeStamps, serieb, timeWindow)
+  detrendSeries <- series - rs@trendSeries
+  detrendSerie1 <- serieb - rs@trendSeries
+
+  # Calculate running variance and standard deviation
+  nRunMn <- rs@nRunMn
+  varianceSeries <- tsEvaNanRunningVariance(detrendSerie1, nRunMn)
+  varianceSeries <- tsEvaNanRunningMean(varianceSeries, ceiling(nRunMn / 2))
+  stdDevSeries1 <- varianceSeries^0.5
+  stdDevSeries <- stdDevSeries1
+  avgStdDev <- mean(stdDevSeries, na.rm = TRUE)
+  S <- 2
+
+  # Calculate error on standard deviation
   N <- timeWindow * 4
-  # computation of the error on the standard deviation explained in
-  # Mentaschi et al 2016
   stdDevError <- avgStdDev * (2 * S^2 / N^3)^(1 / 4)
 
   # Compute running statistics of the stationary series
   statSeries <- detrendSeries / stdDevSeries
+  statSeries_no_na <- stats::na.omit(statSeries)
 
-  xtremS <- statSeries
-  xtremS <- na.omit(xtremS)
-  allS <- na.omit(serieb)
+  running_moments <- tsEvaNanRunningStatistics(statSeries_no_na, nRunMn)
+  statSer3Mom <- tsEvaNanRunningMean(running_moments$rn3mom, ceiling(nRunMn))
+  statSer4Mom <- tsEvaNanRunningMean(running_moments$rn4mom, ceiling(nRunMn))
 
-  statSer3Mom <- tsEvaNanRunningStatistics(statSeries, nRunMn)$rn3mom
-  statSer4Mom <- tsEvaNanRunningStatistics(statSeries, nRunMn)$rn4mom
-  statSer3Mom <- tsEvaNanRunningMean(statSer3Mom, ceiling(nRunMn))
-  statSer4Mom <- tsEvaNanRunningMean(statSer4Mom, ceiling(nRunMn))
-
-
-  # the error on the trend is computed as the error on the average:
-  #  error(average) = stdDev/sqrt(N)
-  trendError <- mean(stdDevSeries) / N^.5
+  # Calculate error on the trend
+  trendError <- avgStdDev / sqrt(N)
 
   # Store the results in a list
-  trasfData <- list(
+  transformed_data <- list(
     runningStatsMulteplicity = nRunMn,
     stationarySeries = statSeries,
     trendSeries = rs@trendSeries,
@@ -324,7 +428,7 @@ tsEvaTransformSeriesToStationaryPeakTrend <- function(timeStamps, series, timeWi
     statSer4Mom = statSer4Mom
   )
 
-  return(trasfData)
+  return(transformed_data)
 }
 
 
@@ -666,7 +770,7 @@ tsEvaTransformSeriesToStationaryTrendAndChangepts <- function(timeStamps, series
   ChgPts=tsEvaChangepts(statSeries,nRunMn/1.5,timeStamps)
 
   #static std
-  statSD=sd(statSeries)
+  statSD=stats::sd(statSeries)
   #ChgptStdDevSeries <- sqrt(ChgPts$variance)/statSD
   ChgptStdDevSeries=1
   statSeries=statSeries-ChgPts$trend
@@ -779,7 +883,7 @@ tsEvaTransformSeriesToStationaryTrendAndChangepts_ciPercentile <- function(timeS
   meanperc=mean(percentileSeries$rnprcnt,na.rm=T)
 
   #here there is a problem
-  stdDev = sd(rs@detrendSeries,na.rm=T);
+  stdDev = stats::sd(rs@detrendSeries,na.rm=T);
   stdDevSeries <- percentileSeries$rnprcnt/meanperc*stdDev
   stdDevError =percentileSeries$stdError/meanperc*stdDev;
   stdDevSeries_1<-stdDevSeries
@@ -792,7 +896,7 @@ tsEvaTransformSeriesToStationaryTrendAndChangepts_ciPercentile <- function(timeS
   ChgPts=tsEvaChangepts(statSeries,nRunMn/1.5,timeStamps)
 
   #static std
-  statSD=sd(statSeries)
+  statSD=stats::sd(statSeries)
   #ChgptStdDevSeries <- sqrt(ChgPts$variance)/statSD
   ChgptStdDevSeries=1
   statSeries=statSeries-ChgPts$trend
@@ -856,7 +960,6 @@ tsEvaTransformSeriesToStationaryTrendAndChangepts_ciPercentile <- function(timeS
 #' @param timeStamps The timestamps corresponding to the time series data.
 #' @param timeWindow The time window for detrending the time series.
 #'
-#' @import stats
 #' @importFrom changepoint cpt.var
 #' @return The trend threshold value.
 #'
@@ -886,66 +989,54 @@ tsEvaTransformSeriesToStationaryTrendAndChangepts_ciPercentile <- function(timeS
 #'tsEvaFindTrendThreshold(series, timeStamps, timeWindow)
 #'
 #' @export
-tsEvaFindTrendThreshold <- function(series, timeStamps, timeWindow){
-  # Initialize variables
-  ptn=timeStamps[which(!is.na(series))]
-  bounds=unique(lubridate::year(ptn))
+tsEvaFindTrendThreshold<-function(series, timeStamps, timeWindow){
+  ptn = timeStamps[which(!is.na(series))]
+  bounds = unique(lubridate::year(ptn))
   nr <- rep(1, length(series))
-  nr=nr +rnorm(length(series),0,1e-5)
+  nr = nr + stats::rnorm(length(series), 0, 1e-05)
   sts <- c()
-  lnegs=c()
-  pctd=c()
-  pcts <- seq(0.40, 0.95, by=0.05)
-  # Iterate over each percentile
-  for (iter in 1:length(pcts)){
-    # Calculate the threshold based on the current percentile
-    thrsdt <- quantile(series, pcts[iter], na.rm=TRUE)
-    # Assign a flag value to missing data
+  lnegs = c()
+  pctd = c()
+  pcts <- seq(0.4, 0.95, by = 0.05)
+  for (iter in 1:length(pcts)) {
+    thrsdt <- stats::quantile(series, pcts[iter], na.rm = TRUE)
     series_no_na <- series
     series_no_na[which(is.na(series_no_na))] <- -9999
-    # Remove data points below the threshold
     serieb <- series_no_na
-    timeb=timeStamps
-    timeb=timeb[-which(serieb < thrsdt)]
+    timeb = timeStamps
+    timeb = timeb[-which(serieb < thrsdt)]
     serieb[which(serieb < thrsdt)] <- NA
-    # Test that all years are represented
     checkY=check_timeseries(timeb,bounds)
-    if (checkY==FALSE){
+    if (checkY == FALSE) {
+      message(paste0("not all years - q= ",pcts[iter]))
       break
     }
-    # Detrend the time series
-    rs <- tsEvaDetrendTimeSeries(timeStamps, serieb, timeWindow,fast=T)
-    varianceSeries <- tsEvaNanRunningVariance(serieb, rs@nRunMn)
-    varianceSeries <- tsEvaNanRunningMean(varianceSeries, ceiling(rs@nRunMn/2))
-    norm_trend <- rs@trendSeries/mean(rs@trendSeries, na.rm=TRUE)
-    dtr1=serieb-rs@trendSeries
-    lneg=length(which(dtr1<0))
-    # Calculate the correlation between the normalized trend and the time series
-    stab <- cor(nr, norm_trend, use = 'pairwise.complete.obs')
-    # Update nr with the current norm_trend if it's the first iteration
-    if(iter == 1) nr <- norm_trend
-    # Store the correlation coefficient in sts
-    if (lneg>=1) lnegs=c(lnegs,lneg)
+    rs <- tsEvaDetrendTimeSeries(timeStamps, serieb, timeWindow,
+                                 fast = T)
+
+    norm_trend <- rs@trendSeries/mean(rs@trendSeries, na.rm = TRUE)
+    dtr1 = serieb - rs@trendSeries
+    lneg = length(which(dtr1 < 0))
+    stab <- stats::cor(nr, norm_trend, use = "pairwise.complete.obs")
+    if (iter == 1)
+      nr <- norm_trend
+    if (lneg >= 1)
+      lnegs = c(lnegs, lneg)
     sts <- c(sts, stab)
-    pctd=c(pctd,pcts[iter])
-
-
+    pctd = c(pctd, pcts[iter])
   }
-  # Set the first correlation coefficient to 1
-  sts[1] <- 1
-  # Perform a changepoint analysis
-  cptm <- try(changepoint::cpt.var(sts, method='AMOC',penalty="BIC", minseglen=3),T)
-  if(inherits(cptm, "try-error")){
-    rval=pctd[which.max(sts[-1])]
+  dow=abs(diff(sts))[-1]
 
-  }else if(cptm@cpts[1] == length(sts)) {
-    message("no change point")
-    cptm@cpts[1] <- length(sts)/2
-    rval=pctd[cptm@cpts[1]]
+  rval = pctd[length(pctd)]
+
+  if(max(dow)>0.2){
+    message("breaking point")
+    rval = pctd[which.max(dow)+1]
   }
-  if (sum(lnegs)>1){
-    rval=pctd[which.min(lnegs)]
+  if (sum(lnegs) > 1) {
+    rval = pctd[which.min(lnegs)]
   }
+
   return(rval)
 }
 
@@ -1027,9 +1118,9 @@ initPercentiles <- function(subsrs, percentM, percent, percentP) {
   probObj$prob <- percent / 100
   probObj$probP <- percentP / 100
 
-  probObj$tM <- quantile(subsrs, probs = percentM / 100, na.rm = T)
-  probObj$t <- quantile(subsrs, probs = percent / 100, na.rm = T)
-  probObj$tP <- quantile(subsrs, probs = percentP / 100, na.rm = T)
+  probObj$tM <- stats::quantile(subsrs, probs = percentM / 100, na.rm = T)
+  probObj$t <- stats::quantile(subsrs, probs = percent / 100, na.rm = T)
+  probObj$tP <- stats::quantile(subsrs, probs = percentP / 100, na.rm = T)
 
   probObj$N <- sum(!is.na(subsrs))
   return(probObj)
@@ -1396,7 +1487,7 @@ tsEvaNanRunningPercentiles <- function(timeStamps, series, windowSize, percent)
   }
   # smoothing output
   rnprcnt <- tsEvaNanRunningMean(rnprcnt0, windowSize)
-  stdError <- sd(rnprcnt0 - rnprcnt)
+  stdError <- stats::sd(rnprcnt0 - rnprcnt)
   return(list(rnprcnt = rnprcnt, stdError = stdError))
 }
 
@@ -1529,11 +1620,11 @@ tsEvaDetrendTimeSeries <- function(timeStamps, series, timeWindow, percent = NA,
 #'cat("computing trend seasonality ...\n")
 #'seasonalitySeries <- rs@detrendSeries
 #'result <- tsEstimateAverageSeasonality(timeStamps, seasonalitySeries, timeWindow=rs@nRunMn)
-#'plot(result$regime, type = "l", xlab = "Day", ylab = "Regime", main = "Estimated Regime")
-#'plot(result$Seasonality$averageSeasonalitySeries, type = "l", xlab = "Day",
-#'ylab = "Seasonality", main = "Average Seasonality")
-#'plot(result$Seasonality$varyingSeasonalitySeries, type = "l", xlab = "Day",
-#'ylab = "Seasonality", main = "Varying Seasonality")
+#'#plot(result$regime, type = "l", xlab = "Day", ylab = "Regime", main = "Estimated Regime")
+#'#plot(result$Seasonality$averageSeasonalitySeries, type = "l", xlab = "Day",
+#'#ylab = "Seasonality", main = "Average Seasonality")
+#'#plot(result$Seasonality$varyingSeasonalitySeries, type = "l", xlab = "Day",
+#'#ylab = "Seasonality", main = "Varying Seasonality")
 #'@importFrom pracma interp1
 #' @export
 tsEstimateAverageSeasonality <- function(timeStamps, seasonalitySeries, timeWindow) {
@@ -1569,7 +1660,7 @@ tsEstimateAverageSeasonality <- function(timeStamps, seasonalitySeries, timeWind
   monthTmStampEnd <- c(timeStamps[which(diff(mond) != 0)], timeStamps[length(timeStamps)])
 
   seasonalitySeries <- data.frame(time = timeStamps, series = seasonalitySeries, month = mony, mond = mond)
-  grpdSsn_ <- aggregate(seasonalitySeries$series,
+  grpdSsn_ <- stats::aggregate(seasonalitySeries$series,
     by = list(month = seasonalitySeries$month),
     FUN = function(x) mean(x, na.rm = T))
 
